from __future__ import unicode_literals

TEST_GROUP = 'test group'
TEST_ROLE_LABEL = 'test role'
TEST_ROLE_LABEL_EDITED = 'test role label edited'
TEST_USER_USERNAME = 'test user'
TEST_USER_PASSWORD = 'test password'
